Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1298)

Unified Diff: third_party/WebKit/Source/platform/image-decoders/ImageAnimation.h

Issue 2878363003: Revert of Fix ImageAnimation constant names after Blink renaming (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/image-decoders/ImageAnimation.h
diff --git a/third_party/WebKit/Source/platform/image-decoders/ImageAnimation.h b/third_party/WebKit/Source/platform/image-decoders/ImageAnimation.h
index 26c84420fba43c69bdb227f33d48ff65483a7e70..de03898545f44173ec1a45af2c6252080ec2abd3 100644
--- a/third_party/WebKit/Source/platform/image-decoders/ImageAnimation.h
+++ b/third_party/WebKit/Source/platform/image-decoders/ImageAnimation.h
@@ -34,17 +34,17 @@
// animated GIF should be cycled. If the loop count is absent, the animation
// cycles once; if it is 0, the animation cycles infinitely; otherwise the
// animation plays n + 1 cycles (where n is the specified loop count). If the
// GIF decoder defaults to kAnimationLoopOnce in the absence of any loop count
// and translates an explicit "0" loop count to kAnimationLoopInfinite, then we
// get a couple of nice side effects:
// * By making kAnimationLoopOnce be 0, we allow the animation cycling code in
// BitmapImage.cpp to avoid special-casing it, and simply treat all
// non-negative loop counts identically.
// * By making the other two constants negative, we avoid conflicts with any
// real loop count values.
-const int kAnimationLoopOnce = 0;
-const int kAnimationLoopInfinite = -1;
-const int kAnimationNone = -2;
+const int kCAnimationLoopOnce = 0;
+const int kCAnimationLoopInfinite = -1;
+const int kCAnimationNone = -2;
} // namespace blink

Powered by Google App Engine
@@ -34,17 +34,17 @@
// cycles once; if it is 0, the animation cycles infinitely; otherwise the
// animation plays n + 1 cycles (where n is the specified loop count). If the
-// GIF decoder defaults to kAnimationLoopOnce in the absence of any loop count
-// and translates an explicit "0" loop count to kAnimationLoopInfinite, then we
+// GIF decoder defaults to kCAnimationLoopOnce in the absence of any loop count
+// and translates an explicit "0" loop count to kCAnimationLoopInfinite, then we
// get a couple of nice side effects:
@@ -34,17 +34,17 @@
// get a couple of nice side effects:
-// * By making kAnimationLoopOnce be 0, we allow the animation cycling code in
-// BitmapImage.cpp to avoid special-casing it, and simply treat all
+// * By making kCAnimationLoopOnce be 0, we allow the animation cycling code
+// in BitmapImage.cpp to avoid special-casing it, and simply treat all
// non-negative loop counts identically.
// * By making the other two constants negative, we avoid conflicts with any
This is Rietveld 408576698